Package: leaflet.extras
Type: Package
Title: Extra Functionality for 'leaflet' Package
Version: 2.0.2
Authors@R: c(
      person("Sebastian", "Gatscha", email = "sebastian_gatscha@gmx.at", role = c("aut")),
      person("Sebastien", "Plutniak", email = "sebastien.plutniak@posteo.net", role = c("cre"), comment = "Package maintainance"),
      person("Bhaskar", "Karambelkar", email = "bhaskarvk@gmail.com", role = c("aut")),
      person("Barret", "Schloerke", email = "barret@rstudio.com", role = c("aut")),
      person("Bangyou", "Zheng", email= "Bangyou.Zheng@csiro.au", role = c("ctb"), comment = "Leaflet-search and Leaflet-GPS plugin integration"),
      person("Robin", "Cura", email= "robin@cura.info", role = c("ctb"), comment = "Fixes for Draw Options"),
      person("Markus", "Voge", email= "markus.voge@ea-aw.de", role = c("ctb"), comment = "Enhancements for Draw Options"),
      person("Markus", "Dumke", role = c("ctb"), comment = "Bounce Marker addition"),
      person(family = "Mapbox", role = c("ctb", "cph"), comment = "leaflet-omnivore, csv2geojson, and togeojson libraries"),
      person("Henry", "Thasler", role = c("ctb", "cph"), comment = "Leaflet.Geodesic library"),
      person("Dennis", "Wilhelm", role = c("ctb", "cph"), comment = "Leaflet.StyleEditor library"),
      person("Kirollos", "Risk", role = c("ctb", "cph"), comment = "fuse.js library"),
      person("Tim", "Wisniewski", role = c("ctb", "cph"), comment = "leaflet-choropleth library"),
      person(family = "Leaflet", role = c("ctb", "cph"), comment = "leaflet-draw library"),
      person("Alexander", "Milevski", role = c("ctb", "cph"), comment = "leaflet-draw-drag library"),
      person("John", "Firebaugh", role = c("ctb", "cph"), comment = "leaflet-fullscreen library"),
      person("Stefano", "Cudini", role = c("ctb", "cph"), comment = "leaflet-gps library"),
      person("Johannes", "Rudolph", role = c("ctb", "cph"), comment = "leaflet-hash library"),
      person("Per", "Liedman", role = c("ctb", "cph"), comment = "leaflet-measure-path library"),
      person("Pavel", "Shramov", role = c("ctb", "cph"), comment = "leaflet-plugins library"),
      person("Filip", "Zavadil", role = c("ctb", "cph"), comment = "leaflet-pulse-icon library"),
      person("Stefano", "Cudini", role = c("ctb", "cph"), comment = "leaflet-search library"),
      person(family = "CliffCloud", role = c("ctb", "cph"), comment = "leaflet-sleep library"),
      person(family = "Ursudio", role = c("ctb", "cph"), comment = "leaflet-webgl-heatmap library"),
      person("Maxime", "Hadjinlian", role = c("ctb", "cph"), comment = "leaflet.BounceMarker library"),
      person("Vladimir", "Agafonkin", role = c("ctb", "cph"), comment = "leaflet.heat library"),
      person("Iván Sánchez", "Ortega", role = c("ctb", "cph"), comment = "leaflet.tilelayer.pouchdbcached library"),
      person("Dale", "Harvey", role = c("ctb", "cph"), comment = "pouchdb-browser library"),
      person("Mike", "Bostock", role = c("ctb", "cph"), comment = "topojson library")
    )
Description: The 'leaflet' JavaScript library provides many plugins some of which
    are available in the core 'leaflet' package, but there are many more. It is not
    possible to support them all in the core 'leaflet' package. This package serves
    as an add-on to the 'leaflet' package by providing extra functionality via 'leaflet'
    plugins.
License: GPL-3 | file LICENSE
Encoding: UTF-8
Depends: R (>= 3.1.0), leaflet (>= 2.0.0)
Imports: htmlwidgets, htmltools, stringr, magrittr
Suggests: jsonlite, readr, sf, xfun, testthat (>= 3.0.0)
URL: https://github.com/sebastien-plutniak/leaflet.extras
BugReports: https://github.com/sebastien-plutniak/leaflet.extras/issues
RoxygenNote: 7.3.3
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-03-28 23:44:49 UTC; seb
Author: Sebastian Gatscha [aut],
  Sebastien Plutniak [cre] (Package maintainance),
  Bhaskar Karambelkar [aut],
  Barret Schloerke [aut],
  Bangyou Zheng [ctb] (Leaflet-search and Leaflet-GPS plugin integration),
  Robin Cura [ctb] (Fixes for Draw Options),
  Markus Voge [ctb] (Enhancements for Draw Options),
  Markus Dumke [ctb] (Bounce Marker addition),
  Mapbox [ctb, cph] (leaflet-omnivore, csv2geojson, and togeojson
    libraries),
  Henry Thasler [ctb, cph] (Leaflet.Geodesic library),
  Dennis Wilhelm [ctb, cph] (Leaflet.StyleEditor library),
  Kirollos Risk [ctb, cph] (fuse.js library),
  Tim Wisniewski [ctb, cph] (leaflet-choropleth library),
  Leaflet [ctb, cph] (leaflet-draw library),
  Alexander Milevski [ctb, cph] (leaflet-draw-drag library),
  John Firebaugh [ctb, cph] (leaflet-fullscreen library),
  Stefano Cudini [ctb, cph] (leaflet-gps library),
  Johannes Rudolph [ctb, cph] (leaflet-hash library),
  Per Liedman [ctb, cph] (leaflet-measure-path library),
  Pavel Shramov [ctb, cph] (leaflet-plugins library),
  Filip Zavadil [ctb, cph] (leaflet-pulse-icon library),
  Stefano Cudini [ctb, cph] (leaflet-search library),
  CliffCloud [ctb, cph] (leaflet-sleep library),
  Ursudio [ctb, cph] (leaflet-webgl-heatmap library),
  Maxime Hadjinlian [ctb, cph] (leaflet.BounceMarker library),
  Vladimir Agafonkin [ctb, cph] (leaflet.heat library),
  Iván Sánchez Ortega [ctb, cph] (leaflet.tilelayer.pouchdbcached
    library),
  Dale Harvey [ctb, cph] (pouchdb-browser library),
  Mike Bostock [ctb, cph] (topojson library)
Maintainer: Sebastien Plutniak <sebastien.plutniak@posteo.net>
Repository: CRAN
Date/Publication: 2026-03-29 15:50:08 UTC
Built: R 4.6.0; ; 2026-04-26 19:23:20 UTC; unix
