# Generated by roxygen2: do not edit by hand

S3method("[",leaflet_pulse_icon_set)
S3method("[",leaflet_weather_icon_set)
export(activateGPS)
export(addAwesomeMarkersDependencies)
export(addBingTiles)
export(addBootstrapDependency)
export(addBounceMarkers)
export(addCSV)
export(addCSVHeatmap)
export(addControlGPS)
export(addDrawToolbar)
export(addFullscreenControl)
export(addGPX)
export(addGPXHeatmap)
export(addGeoJSONChoropleth)
export(addGeoJSONHeatmap)
export(addGeoJSONv2)
export(addGeodesicPolylines)
export(addGreatCircles)
export(addGroupedBaseLayer)
export(addGroupedLayersControl)
export(addGroupedOverlay)
export(addHash)
export(addHeatmap)
export(addKML)
export(addKMLChoropleth)
export(addKMLHeatmap)
export(addLatLng)
export(addMeasurePathToolbar)
export(addPulseMarkers)
export(addResetMapButton)
export(addReverseSearchGoogle)
export(addReverseSearchOSM)
export(addSearchFeatures)
export(addSearchGoogle)
export(addSearchOSM)
export(addSearchUSCensusBureau)
export(addStyleEditor)
export(addWMSLegend)
export(addWeatherMarkers)
export(addWebGLCSVHeatmap)
export(addWebGLGPXHeatmap)
export(addWebGLGeoJSONHeatmap)
export(addWebGLHeatmap)
export(addWebGLKMLHeatmap)
export(clearHeatmap)
export(clearSearchFeatures)
export(clearSearchOSM)
export(clearWebGLHeatmap)
export(csvParserOptions)
export(deactivateGPS)
export(debugMap)
export(drawCircleMarkerOptions)
export(drawCircleOptions)
export(drawMarkerOptions)
export(drawPolygonOptions)
export(drawPolylineOptions)
export(drawRectangleOptions)
export(drawShapeOptions)
export(editToolbarOptions)
export(edithandlersOptions)
export(edittoolbarOptions)
export(enableMeasurePath)
export(enableTileCaching)
export(gpsOptions)
export(groupedLayersControlOptions)
export(handlersOptions)
export(leafletExtrasDependencies)
export(legendOptions)
export(makePulseIcon)
export(makeWeatherIcon)
export(measurePathOptions)
export(propsToHTML)
export(propstoHTMLTable)
export(pulseIconList)
export(pulseIcons)
export(removeControlGPS)
export(removeDrawToolbar)
export(removeGroupedLayersControl)
export(removeGroupedOverlay)
export(removeHeatmap)
export(removeSearchFeatures)
export(removeSearchGoogle)
export(removeSearchOSM)
export(removeSearchUSCensusBureau)
export(removeStyleEditor)
export(removeWebGLHeatmap)
export(searchFeaturesOptions)
export(searchOSMText)
export(searchOptions)
export(selectedPathOptions)
export(setMapWidgetStyle)
export(suspendScroll)
export(toolbarOptions)
export(weatherIconList)
export(weatherIcons)
import(leaflet)
importFrom(magrittr,"%>%")
importFrom(stats,setNames)
